/// <reference types="react" />
import { IProstoreSsrContext } from '@proscom/prostore';
/**
 * React context which holds ProstoreSsrManager instance
 */
export declare const ProstoreSsrContext: import("react").Context<ProstoreSsrManager | null>;
export declare type IStates = {
    [name: string]: any;
};
export interface IProstoreSsrManagerParams {
    /** Whether the application is running on the server or in the browser */
    isServer?: boolean;
    /** Initial states of the stores. Usually provided in the browser when the SSR data is received */
    initialStates?: IStates;
}
/**
 * Globally manages the store states for them to be used in the SSR-enabled environments
 */
export declare class ProstoreSsrManager implements IProstoreSsrContext {
    /** Whether the application is running on the server or in the browser */
    isServer: boolean;
    /** Store states identified by store's ssrId */
    states: IStates;
    /** Array of registered promises to be awaited during the SSR */
    promises: Set<Promise<any>>;
    /** Do nothing if this is true. setState will do nothing and getState will return null */
    disabled: boolean;
    constructor({ isServer, initialStates }: IProstoreSsrManagerParams);
    /**
     * Registers the promise from the store for it to be awaited during SSR
     *
     * @param promise - promise to be registered
     */
    registerPromise(promise: Promise<any>): void;
    /**
     * Checks if it has any registered promises
     */
    hasPromises(): boolean;
    /**
     * Awaits all current promises
     */
    waitForCurrentPromises(): Promise<any>;
    /**
     * Returns the saved state for the store with the provided ssrId
     * @param key - ssrId of the store
     * @returns saved state for the provided store
     */
    getState(key: string): any;
    /**
     * Saves the state of the store with the provided ssrId
     * @param key - ssrId of the store
     * @param value - state to be saved
     */
    setState(key: string, value: any): void;
    /**
     * Returns all store states
     */
    getStates(): IStates;
    /**
     * Changes the disabled flag
     * @param value - new value of the flag
     */
    setDisabled(value: boolean): void;
}
