import { useEffect, useState } from 'react';
/**
 * Subscribe to Observable
 */
export function useObservable(obs$, setState) {
    useEffect(function () {
        if (!obs$) {
            return;
        }
        var sub = obs$.subscribe(function (state) {
            setState(state);
        });
        return function () {
            sub.unsubscribe();
        };
    }, [obs$, setState]);
}
/**
 * Subscribe to Observable with useState included
 */
export function useObservableState(obs$, initialState) {
    if (initialState === void 0) { initialState = null; }
    var _a = useState(initialState), state = _a[0], setState = _a[1];
    useObservable(obs$, setState);
    return state;
}
/**
 * Subscribe to BehaviorSubject
 */
export function useSubject(sub$) {
    var _a;
    return useObservableState(sub$, (_a = sub$ === null || sub$ === void 0 ? void 0 : sub$.value) !== null && _a !== void 0 ? _a : null);
}
//# sourceMappingURL=useObservable.js.map