import { CheckRequestResult, CheckRequestStateFn, GetRequestStoreData, GetRequestStoreOptions, GetRequestStoreState, GetRequestStoreVars, RequestStore } from '@proscom/prostore';
export interface UseRequestStoreResult<Store extends RequestStore> {
    check: CheckRequestResult;
    state: GetRequestStoreState<Store>;
    load: (options?: GetRequestStoreOptions<Store>) => Promise<GetRequestStoreState<Store>>;
    store: Store;
}
export interface UseRequestOptions<Vars = any, Data = any> {
    checkRequest?: CheckRequestStateFn<Vars, Data>;
}
/**
 * Attaches component to the provided store and requests data based on the variables and options
 *
 * @param storeOrName - RequestStore to subscribe to, or its name for it to be injected from the context
 * @param variables - Request variables. If they change, request will be fired again
 * @param options - Additional request options. They are not observed
 * @param hookOptions - Additional hook options:
 *  - checkRequest - Optional function which may be used to override default behavior of determining
 *                   when to fire the request
 */
export declare function useRequestStore<Store extends RequestStore>(storeOrName: string | Store, variables?: GetRequestStoreVars<Store> | undefined, options?: GetRequestStoreOptions<Store> | undefined, hookOptions?: UseRequestOptions<GetRequestStoreVars<Store>, GetRequestStoreData<Store>>): UseRequestStoreResult<Store>;
