"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAsyncOperationFeedback = void 0;
var react_1 = require("react");
var ui_react_1 = require("@proscom/ui-react");
/**
 * Allows to observe the status of async operation
 * @param callback - async callback which performs the operation
 * @example
 *  const [run, loading] = useAsyncOperation(() => fetch('url').catch(e => console.error(e)));
 *  return <div>{loading ? 'Loading...' : <button onClick={run} />}
 */
function useAsyncOperationFeedback(callback) {
    var _a = react_1.useState(0), loading = _a[0], setLoading = _a[1];
    var mountedRef = ui_react_1.useMountedRef();
    var callbackRef = ui_react_1.useLatestCallbackRef(callback);
    var run = react_1.useCallback(function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        setLoading(function (s) { return s + 1; });
        return callbackRef.apply(void 0, args).then(function (result) {
            if (mountedRef.current) {
                setLoading(function (s) { return s - 1; });
            }
            return result;
        }, function (e) {
            if (mountedRef.current) {
                setLoading(function (s) { return s - 1; });
            }
            throw e;
        });
    }, []);
    return [run, loading > 0];
}
exports.useAsyncOperationFeedback = useAsyncOperationFeedback;
//# sourceMappingURL=useAsyncOperationFeedback.js.map