import { Observable } from 'rxjs';
import { useEffect, useState } from 'react';
import { ObservableWithValue } from "@proscom/prostore";

/**
 * Subscribe to Observable
 */
export function useObservable<State = any>(
  obs$: Observable<State>|null|undefined,
  setState: (state: State) => any
) {
  useEffect(() => {
    if (!obs$) {
      return;
    }
    const sub = obs$.subscribe((state: State) => {
      setState(state);
    });
    return () => {
      sub.unsubscribe();
    };
  }, [obs$, setState]);
}

export function useObservableState<State = any>(
  obs$: Observable<State>|null|undefined,
  initialState: State
): State;
export function useObservableState<State = any>(
  obs$: Observable<State>|null|undefined
): State | null;
/**
 * Subscribe to Observable with useState included
 */
export function useObservableState<State = any>(
  obs$: Observable<State>|null|undefined,
  initialState: State | null = null
): State | null {
  const [state, setState] = useState(initialState);
  useObservable(obs$, setState);
  return state;
}

export function useSubject<State = any>(sub$: ObservableWithValue<State>): State;
export function useSubject<State = any>(sub$: ObservableWithValue<State>|null|undefined): State|null;
/**
 * Subscribe to BehaviorSubject
 */
export function useSubject<State = any>(sub$: ObservableWithValue<State>|null|undefined) {
  return useObservableState(sub$, sub$?.value ?? null);
}
